# Copyright 2021-2022 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

import logging
import ssl
import uuid
from typing import Optional, Union
from urllib.parse import urlparse

import httpx
from requests_toolbelt import user_agent
from tenacity import retry, stop_after_attempt, wait_exponential

import cerbos
from cerbos.sdk.model import *

TLSVerify = Union[str, bool, ssl.SSLContext]


class AsyncRetryClient(httpx.AsyncClient):
    def __init__(self, request_retries: int = 0, *args, **kwargs):
        self._client = httpx.AsyncClient(*args, **kwargs)

        fn = self._client.post
        if request_retries:
            # 1+n because 1 == the initial attempt
            self._post_fn = retry(
                stop=stop_after_attempt(1 + request_retries),
                wait=wait_exponential(multiplier=1, min=1, max=10),
            )(fn)
        else:
            self._post_fn = fn

    # By coincidence, we only want to allow retries on both of the `post` use cases on the http client, and
    # not any other methods. Therefore, we can conveniently globally wrap the `post` method.
    # We'll need to adapt this if we want more specificity in the future.
    def post(self, *args, **kwargs):
        return self._post_fn(*args, **kwargs)

    def __getattr__(self, attr):
        return getattr(self._client, attr)


class AsyncCerbosClient:
    """Client for accessing the Cerbos API

    Args:
        host (str): The full address of the Cerbos API server (PDP)
        timeout_secs (float): Request timeout in seconds (default is 2)
        tls_verify (bool|str|SSLContext): If False, disables server certificate verification. If a path is passed it is used as the CA certificate
        playground_instance (str): Optional Cerbos Playground ID if testing against a Playground playground_instance
        raise_on_error (bool): Raise an exception on unsuccessful requests (default is False)
        debug (bool): Log request and response
        logger (Logger): Logger to use for logging

    Example:
        with CerbosClient("http://localhost:3592") as cerbos:
            if cerbos.is_allowed(
                "view",
                Principal(id="john", roles={"employee"}, attr={"geography":"GB"}),
                Resource(id="XX125", "kind"="leave_request", attr={"geography":"GB"})
                ):
                do_thing()
    """

    _http: httpx.AsyncClient
    _logger: logging.Logger
    _raise_on_error: bool

    def __init__(
        self,
        host: str,
        *,
        timeout_secs: float = 2.0,
        tls_verify: TLSVerify = True,
        playground_instance: Optional[str] = None,
        raise_on_error: bool = False,
        request_retries: int = 0,
        connection_retries: int = 0,
        debug: bool = False,
        logger: logging.Logger = logging.getLogger(__name__),
    ):
        self._logger = logger
        self._raise_on_error = raise_on_error

        ua = user_agent("cerbos-python", cerbos.__version__)
        headers = {"User-Agent": ua}

        if playground_instance is not None:
            headers.update({"playground-instance": playground_instance})

        event_hooks = {"response": []}
        if debug:
            event_hooks["response"].append(self._log_response)

        if raise_on_error:
            event_hooks["response"].append(self._raise_on_status)

        transport_params = {}
        base_url = host

        url = urlparse(host)
        if url.scheme == "unix" or url.scheme == "unix+http":
            transport_params["uds"] = url.path
            base_url = "http://cerbos.sock"
        elif url.scheme == "unix+https":
            transport_params |= {"uds": url.path, "verify": tls_verify}
            base_url = "https://cerbos.sock"

        if connection_retries:
            transport_params["retries"] = connection_retries

        transport = None
        if transport_params:
            transport = httpx.AsyncHTTPTransport(**transport_params)

        self._http = AsyncRetryClient(
            base_url=base_url,
            headers=headers,
            timeout=timeout_secs,
            verify=tls_verify,
            event_hooks=event_hooks,
            transport=transport,
            request_retries=request_retries,
        )

    async def _raise_on_status(self, response: httpx.Response):
        if response is None:
            return

        response.raise_for_status()

    async def _log_response(self, response: httpx.Response):
        if response is None:
            return

        req_prefix = "< "
        res_prefix = "> "
        request = response.request
        output = []

        await response.aread()

        output.append(f"{req_prefix}{request.method} {request.url}")

        for name, value in request.headers.items():
            output.append(f"{req_prefix}{name}: {value}")

        output.append(req_prefix)

        if isinstance(request.content, (str, bytes)):
            output.append(f"{req_prefix}{request.content}")
        else:
            output.append("<< Request body is not a string-like type >>")

        output.append("")

        output.append(f"{res_prefix}{response.status_code} {response.reason_phrase}")

        for name, value in response.headers.items():
            output.append(f"{res_prefix}{name}: {value}")

        output.append(res_prefix)

        output.append(f"{res_prefix}{response.text}")

        msg = "\n".join(output)
        self._logger.debug(msg)

    async def __aenter__(self):
        return self

    async def __aexit__(self, *args):
        await self.close()

    async def check_resources(
        self,
        principal: Principal,
        resources: ResourceList,
        request_id: Optional[str] = None,
        aux_data: Optional[AuxData] = None,
    ) -> CheckResourcesResponse:
        """Check permissions for a list of resources

        Args:
            principal (Principal): principal who is performing the action
            resources (ResourceList): list of resources to check permissions for
            request_id (None|str): request ID for the request (default None)
            aux_data (None|AuxData): auxiliary data for the request
        """

        req_id = _get_request_id(request_id)
        req = CheckResourcesRequest(
            request_id=req_id,
            principal=principal,
            resources=resources.resources,
            aux_data=aux_data,
        )
        resp = await self._http.post("/api/check/resources", json=req.to_dict())
        if resp.is_error:
            if self._raise_on_error:
                raise CerbosRequestException(APIError.from_dict(resp.json()))

            return CheckResourcesResponse(
                request_id=req_id,
                status_code=resp.status_code,
                status_msg=APIError.from_dict(resp.json()),
            )

        return CheckResourcesResponse.from_dict(resp.json())

    async def is_allowed(
        self,
        action: str,
        principal: Principal,
        resource: Resource,
        request_id: Optional[str] = None,
        aux_data: Optional[AuxData] = None,
    ) -> bool:
        """Check permission for a single action

        Args:
            action (str): action being performed
            principal (Principal): principal who is performing the action
            resource (Resource): resource on which the action is being performed
            request_id (None|str): request ID for the request (default None)
            aux_data (None|AuxData): auxiliary data for the request
        """
        resp = await self.check_resources(
            principal=principal,
            resources=ResourceList().add(resource, {action}),
            request_id=request_id,
            aux_data=aux_data,
        )

        if (r := resp.get_resource(resource.id)) is not None:
            return r.is_allowed(action)

        return False

    async def plan_resources(
        self,
        action: str,
        principal: Principal,
        resource: ResourceDesc,
        request_id: Optional[str] = None,
        aux_data: Optional[AuxData] = None,
    ) -> PlanResourcesResponse:
        """Create a query plan for performing the given action on resources of the given kind

        Args:
            action (str): Action to perform
            principal (Principal): principal who is performing the action
            resource (ResourceDesc): information about the resource kind
            request_id (None|str): request ID for the request (default None)
            aux_data (None|AuxData): auxiliary data for the request
        """

        req_id = _get_request_id(request_id)
        req = PlanResourcesRequest(
            request_id=req_id,
            action=action,
            principal=principal,
            resource=resource,
            aux_data=aux_data,
        )

        resp = await self._http.post("/api/plan/resources", json=req.to_dict())
        if resp.is_error:
            if self._raise_on_error:
                raise CerbosRequestException(APIError.from_dict(resp.json()))

            return PlanResourcesResponse(
                request_id=req_id,
                status_code=resp.status_code,
                status_msg=APIError.from_dict(resp.json()),
                action=action,
                resource_kind=resource.kind,
                policy_version=resource.policy_version,
            )

        return PlanResourcesResponse.from_dict(resp.json())

    async def is_healthy(self, svc: Optional[str] = None) -> bool:
        """Checks the health of the Cerbos endpoint"""

        params = None if svc is None else {"service": svc}
        try:
            resp = await self._http.get("/_cerbos/health", params=params)
            return resp.is_success
        except Exception:
            return False

    def with_principal(
        self, principal: Principal, aux_data: Optional[AuxData] = None
    ) -> "AsyncPrincipalContext":
        """Fixes the principal for subsequent requests"""

        return AsyncPrincipalContext(self, principal, aux_data)

    async def close(self):
        await self._http.aclose()


class AsyncPrincipalContext:
    """A special Cerbos client where the principal and auxData are fixed"""

    _client: AsyncCerbosClient
    _principal: Principal
    _aux_data: Optional[AuxData]

    def __init__(
        self,
        client: AsyncCerbosClient,
        principal: Principal,
        aux_data: Optional[AuxData] = None,
    ):
        self._client = client
        self._principal = principal
        self._aux_data = aux_data

    async def check_resources(
        self, resources: ResourceList, request_id: Optional[str] = None
    ) -> CheckResourcesResponse:
        """Check permissions for a list of resources

        Args:
            resources (ResourceList): list of resources to check permissions for
            request_id (None|str): request ID for the request (default None)
        """

        return await self._client.check_resources(
            principal=self._principal,
            resources=resources,
            request_id=request_id,
            aux_data=self._aux_data,
        )

    async def plan_resources(
        self,
        action: str,
        resource: ResourceDesc,
        request_id: Optional[str] = None,
        aux_data: Optional[AuxData] = None,
    ) -> PlanResourcesResponse:
        """Create a query plan for performing the given action on resources of the given kind

        Args:
            action (str): Action to perform
            resource (ResourceDesc): information about the resource kind
            request_id (None|str): request ID for the request (default None)
            aux_data (None|AuxData): auxiliary data for the request
        """

        return await self._client.plan_resources(
            action=action,
            principal=self._principal,
            resource=resource,
            request_id=request_id,
            aux_data=aux_data,
        )

    async def is_allowed(
        self, action: str, resource: Resource, request_id: Optional[str] = None
    ) -> bool:
        """Check permission for a single action

        Args:
            action (str): action being performed
            resource (Resource): resource on which the action is being performed
            request_id (None|str): request ID for the request (default None)
        """

        return await self._client.is_allowed(
            action=action,
            principal=self._principal,
            resource=resource,
            request_id=request_id,
            aux_data=self._aux_data,
        )


def _get_request_id(request_id: Optional[str]) -> str:
    if request_id is None:
        return str(uuid.uuid4())

    return request_id



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protoc-gen-openapiv2/options/openapiv2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,protoc-gen-openapiv2/options/openapiv2.proto\x12)grpc.gateway.protoc_gen_openapiv2.options\x1a\x1cgoogle/protobuf/struct.proto\"\xb3\x08\n\x07Swagger\x12\x18\n\x07swagger\x18\x01 \x01(\tR\x07swagger\x12\x43\n\x04info\x18\x02 \x01(\x0b\x32/.grpc.gateway.protoc_gen_openapiv2.options.InfoR\x04info\x12\x12\n\x04host\x18\x03 \x01(\tR\x04host\x12\x1b\n\tbase_path\x18\x04 \x01(\tR\x08\x62\x61sePath\x12K\n\x07schemes\x18\x05 \x03(\x0e\x32\x31.grpc.gateway.protoc_gen_openapiv2.options.SchemeR\x07schemes\x12\x1a\n\x08\x63onsumes\x18\x06 \x03(\tR\x08\x63onsumes\x12\x1a\n\x08produces\x18\x07 \x03(\tR\x08produces\x12_\n\tresponses\x18\n \x03(\x0b\x32\x41.grpc.gateway.protoc_gen_openapiv2.options.Swagger.ResponsesEntryR\tresponses\x12q\n\x14security_definitions\x18\x0b \x01(\x0b\x32>.grpc.gateway.protoc_gen_openapiv2.options.SecurityDefinitionsR\x13securityDefinitions\x12Z\n\x08security\x18\x0c \x03(\x0b\x32>.grpc.gateway.protoc_gen_openapiv2.options.SecurityRequirementR\x08security\x12\x42\n\x04tags\x18\r \x03(\x0b\x32..grpc.gateway.protoc_gen_openapiv2.options.TagR\x04tags\x12\x65\n\rexternal_docs\x18\x0e \x01(\x0b\x32@.grpc.gateway.protoc_gen_openapiv2.options.ExternalDocumentationR\x0c\x65xternalDocs\x12\x62\n\nextensions\x18\x0f \x03(\x0b\x32\x42.grpc.gateway.protoc_gen_openapiv2.options.Swagger.ExtensionsEntryR\nextensions\x1aq\n\x0eResponsesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.grpc.gateway.protoc_gen_openapiv2.options.ResponseR\x05value:\x02\x38\x01\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\xd6\x07\n\tOperation\x12\x12\n\x04tags\x18\x01 \x03(\tR\x04tags\x12\x18\n\x07summary\x18\x02 \x01(\tR\x07summary\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x65\n\rexternal_docs\x18\x04 \x01(\x0b\x32@.grpc.gateway.protoc_gen_openapiv2.options.ExternalDocumentationR\x0c\x65xternalDocs\x12!\n\x0coperation_id\x18\x05 \x01(\tR\x0boperationId\x12\x1a\n\x08\x63onsumes\x18\x06 \x03(\tR\x08\x63onsumes\x12\x1a\n\x08produces\x18\x07 \x03(\tR\x08produces\x12\x61\n\tresponses\x18\t \x03(\x0b\x32\x43.grpc.gateway.protoc_gen_openapiv2.options.Operation.ResponsesEntryR\tresponses\x12K\n\x07schemes\x18\n \x03(\x0e\x32\x31.grpc.gateway.protoc_gen_openapiv2.options.SchemeR\x07schemes\x12\x1e\n\ndeprecated\x18\x0b \x01(\x08R\ndeprecated\x12Z\n\x08security\x18\x0c \x03(\x0b\x32>.grpc.gateway.protoc_gen_openapiv2.options.SecurityRequirementR\x08security\x12\x64\n\nextensions\x18\r \x03(\x0b\x32\x44.grpc.gateway.protoc_gen_openapiv2.options.Operation.ExtensionsEntryR\nextensions\x12U\n\nparameters\x18\x0e \x01(\x0b\x32\x35.grpc.gateway.protoc_gen_openapiv2.options.ParametersR\nparameters\x1aq\n\x0eResponsesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.grpc.gateway.protoc_gen_openapiv2.options.ResponseR\x05value:\x02\x38\x01\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01J\x04\x08\x08\x10\t\"b\n\nParameters\x12T\n\x07headers\x18\x01 \x03(\x0b\x32:.grpc.gateway.protoc_gen_openapiv2.options.HeaderParameterR\x07headers\"\xa3\x02\n\x0fHeaderParameter\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12S\n\x04type\x18\x03 \x01(\x0e\x32?.grpc.gateway.protoc_gen_openapiv2.options.HeaderParameter.TypeR\x04type\x12\x16\n\x06\x66ormat\x18\x04 \x01(\tR\x06\x66ormat\x12\x1a\n\x08required\x18\x05 \x01(\x08R\x08required\"E\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"\xd8\x01\n\x06Header\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x66ormat\x18\x03 \x01(\tR\x06\x66ormat\x12\x18\n\x07\x64\x65\x66\x61ult\x18\x06 \x01(\tR\x07\x64\x65\x66\x61ult\x12\x18\n\x07pattern\x18\r \x01(\tR\x07patternJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13\"\x9a\x05\n\x08Response\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12I\n\x06schema\x18\x02 \x01(\x0b\x32\x31.grpc.gateway.protoc_gen_openapiv2.options.SchemaR\x06schema\x12Z\n\x07headers\x18\x03 \x03(\x0b\x32@.grpc.gateway.protoc_gen_openapiv2.options.Response.HeadersEntryR\x07headers\x12]\n\x08\x65xamples\x18\x04 \x03(\x0b\x32\x41.grpc.gateway.protoc_gen_openapiv2.options.Response.ExamplesEntryR\x08\x65xamples\x12\x63\n\nextensions\x18\x05 \x03(\x0b\x32\x43.grpc.gateway.protoc_gen_openapiv2.options.Response.ExtensionsEntryR\nextensions\x1am\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x31.grpc.gateway.protoc_gen_openapiv2.options.HeaderR\x05value:\x02\x38\x01\x1a;\n\rExamplesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xd6\x03\n\x04Info\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12(\n\x10terms_of_service\x18\x03 \x01(\tR\x0etermsOfService\x12L\n\x07\x63ontact\x18\x04 \x01(\x0b\x32\x32.grpc.gateway.protoc_gen_openapiv2.options.ContactR\x07\x63ontact\x12L\n\x07license\x18\x05 \x01(\x0b\x32\x32.grpc.gateway.protoc_gen_openapiv2.options.LicenseR\x07license\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\x12_\n\nextensions\x18\x07 \x03(\x0b\x32?.grpc.gateway.protoc_gen_openapiv2.options.Info.ExtensionsEntryR\nextensions\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"E\n\x07\x43ontact\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\"/\n\x07License\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"K\n\x15\x45xternalDocumentation\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"\xaa\x02\n\x06Schema\x12V\n\x0bjson_schema\x18\x01 \x01(\x0b\x32\x35.grpc.gateway.protoc_gen_openapiv2.options.JSONSchemaR\njsonSchema\x12$\n\rdiscriminator\x18\x02 \x01(\tR\rdiscriminator\x12\x1b\n\tread_only\x18\x03 \x01(\x08R\x08readOnly\x12\x65\n\rexternal_docs\x18\x05 \x01(\x0b\x32@.grpc.gateway.protoc_gen_openapiv2.options.ExternalDocumentationR\x0c\x65xternalDocs\x12\x18\n\x07\x65xample\x18\x06 \x01(\tR\x07\x65xampleJ\x04\x08\x04\x10\x05\"\xd7\n\n\nJSONSchema\x12\x10\n\x03ref\x18\x03 \x01(\tR\x03ref\x12\x14\n\x05title\x18\x05 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x06 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07\x64\x65\x66\x61ult\x18\x07 \x01(\tR\x07\x64\x65\x66\x61ult\x12\x1b\n\tread_only\x18\x08 \x01(\x08R\x08readOnly\x12\x18\n\x07\x65xample\x18\t \x01(\tR\x07\x65xample\x12\x1f\n\x0bmultiple_of\x18\n \x01(\x01R\nmultipleOf\x12\x18\n\x07maximum\x18\x0b \x01(\x01R\x07maximum\x12+\n\x11\x65xclusive_maximum\x18\x0c \x01(\x08R\x10\x65xclusiveMaximum\x12\x18\n\x07minimum\x18\r \x01(\x01R\x07minimum\x12+\n\x11\x65xclusive_minimum\x18\x0e \x01(\x08R\x10\x65xclusiveMinimum\x12\x1d\n\nmax_length\x18\x0f \x01(\x04R\tmaxLength\x12\x1d\n\nmin_length\x18\x10 \x01(\x04R\tminLength\x12\x18\n\x07pattern\x18\x11 \x01(\tR\x07pattern\x12\x1b\n\tmax_items\x18\x14 \x01(\x04R\x08maxItems\x12\x1b\n\tmin_items\x18\x15 \x01(\x04R\x08minItems\x12!\n\x0cunique_items\x18\x16 \x01(\x08R\x0buniqueItems\x12%\n\x0emax_properties\x18\x18 \x01(\x04R\rmaxProperties\x12%\n\x0emin_properties\x18\x19 \x01(\x04R\rminProperties\x12\x1a\n\x08required\x18\x1a \x03(\tR\x08required\x12\x14\n\x05\x61rray\x18\" \x03(\tR\x05\x61rray\x12_\n\x04type\x18# \x03(\x0e\x32K.grpc.gateway.protoc_gen_openapiv2.options.JSONSchema.JSONSchemaSimpleTypesR\x04type\x12\x16\n\x06\x66ormat\x18$ \x01(\tR\x06\x66ormat\x12\x12\n\x04\x65num\x18. \x03(\tR\x04\x65num\x12z\n\x13\x66ield_configuration\x18\xe9\x07 \x01(\x0b\x32H.grpc.gateway.protoc_gen_openapiv2.options.JSONSchema.FieldConfigurationR\x12\x66ieldConfiguration\x12\x65\n\nextensions\x18\x30 \x03(\x0b\x32\x45.grpc.gateway.protoc_gen_openapiv2.options.JSONSchema.ExtensionsEntryR\nextensions\x1a<\n\x12\x46ieldConfiguration\x12&\n\x0fpath_param_name\x18/ \x01(\tR\rpathParamName\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"w\n\x15JSONSchemaSimpleTypes\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41RRAY\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\x08\n\x04NULL\x10\x04\x12\n\n\x06NUMBER\x10\x05\x12\n\n\x06OBJECT\x10\x06\x12\n\n\x06STRING\x10\x07J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x17\x10\x18J\x04\x08\x1b\x10\x1cJ\x04\x08\x1c\x10\x1dJ\x04\x08\x1d\x10\x1eJ\x04\x08\x1e\x10\"J\x04\x08%\x10*J\x04\x08*\x10+J\x04\x08+\x10.\"\xd9\x02\n\x03Tag\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x65\n\rexternal_docs\x18\x03 \x01(\x0b\x32@.grpc.gateway.protoc_gen_openapiv2.options.ExternalDocumentationR\x0c\x65xternalDocs\x12^\n\nextensions\x18\x04 \x03(\x0b\x32>.grpc.gateway.protoc_gen_openapiv2.options.Tag.ExtensionsEntryR\nextensions\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xf7\x01\n\x13SecurityDefinitions\x12h\n\x08security\x18\x01 \x03(\x0b\x32L.grpc.gateway.protoc_gen_openapiv2.options.SecurityDefinitions.SecurityEntryR\x08security\x1av\n\rSecurityEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12O\n\x05value\x18\x02 \x01(\x0b\x32\x39.grpc.gateway.protoc_gen_openapiv2.options.SecuritySchemeR\x05value:\x02\x38\x01\"\xff\x06\n\x0eSecurityScheme\x12R\n\x04type\x18\x01 \x01(\x0e\x32>.grpc.gateway.protoc_gen_openapiv2.options.SecurityScheme.TypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12L\n\x02in\x18\x04 \x01(\x0e\x32<.grpc.gateway.protoc_gen_openapiv2.options.SecurityScheme.InR\x02in\x12R\n\x04\x66low\x18\x05 \x01(\x0e\x32>.grpc.gateway.protoc_gen_openapiv2.options.SecurityScheme.FlowR\x04\x66low\x12+\n\x11\x61uthorization_url\x18\x06 \x01(\tR\x10\x61uthorizationUrl\x12\x1b\n\ttoken_url\x18\x07 \x01(\tR\x08tokenUrl\x12I\n\x06scopes\x18\x08 \x01(\x0b\x32\x31.grpc.gateway.protoc_gen_openapiv2.options.ScopesR\x06scopes\x12i\n\nextensions\x18\t \x03(\x0b\x32I.grpc.gateway.protoc_gen_openapiv2.options.SecurityScheme.ExtensionsEntryR\nextensions\x1aU\n\x0f\x45xtensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"K\n\x04Type\x12\x10\n\x0cTYPE_INVALID\x10\x00\x12\x0e\n\nTYPE_BASIC\x10\x01\x12\x10\n\x0cTYPE_API_KEY\x10\x02\x12\x0f\n\x0bTYPE_OAUTH2\x10\x03\"1\n\x02In\x12\x0e\n\nIN_INVALID\x10\x00\x12\x0c\n\x08IN_QUERY\x10\x01\x12\r\n\tIN_HEADER\x10\x02\"j\n\x04\x46low\x12\x10\n\x0c\x46LOW_INVALID\x10\x00\x12\x11\n\rFLOW_IMPLICIT\x10\x01\x12\x11\n\rFLOW_PASSWORD\x10\x02\x12\x14\n\x10\x46LOW_APPLICATION\x10\x03\x12\x14\n\x10\x46LOW_ACCESS_CODE\x10\x04\"\xf6\x02\n\x13SecurityRequirement\x12\x8a\x01\n\x14security_requirement\x18\x01 \x03(\x0b\x32W.grpc.gateway.protoc_gen_openapiv2.options.SecurityRequirement.SecurityRequirementEntryR\x13securityRequirement\x1a\x30\n\x18SecurityRequirementValue\x12\x14\n\x05scope\x18\x01 \x03(\tR\x05scope\x1a\x9f\x01\n\x18SecurityRequirementEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12m\n\x05value\x18\x02 \x01(\x0b\x32W.grpc.gateway.protoc_gen_openapiv2.options.SecurityRequirement.SecurityRequirementValueR\x05value:\x02\x38\x01\"\x96\x01\n\x06Scopes\x12R\n\x05scope\x18\x01 \x03(\x0b\x32<.grpc.gateway.protoc_gen_openapiv2.options.Scopes.ScopeEntryR\x05scope\x1a\x38\n\nScopeEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*;\n\x06Scheme\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\x12\x06\n\x02WS\x10\x03\x12\x07\n\x03WSS\x10\x04\x42HZFgithub.com/grpc-ecosystem/grpc-gateway/v2/protoc-gen-openapiv2/optionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protoc_gen_openapiv2.options.openapiv2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZFgithub.com/grpc-ecosystem/grpc-gateway/v2/protoc-gen-openapiv2/options'
  _SWAGGER_RESPONSESENTRY._options = None
  _SWAGGER_RESPONSESENTRY._serialized_options = b'8\001'
  _SWAGGER_EXTENSIONSENTRY._options = None
  _SWAGGER_EXTENSIONSENTRY._serialized_options = b'8\001'
  _OPERATION_RESPONSESENTRY._options = None
  _OPERATION_RESPONSESENTRY._serialized_options = b'8\001'
  _OPERATION_EXTENSIONSENTRY._options = None
  _OPERATION_EXTENSIONSENTRY._serialized_options = b'8\001'
  _RESPONSE_HEADERSENTRY._options = None
  _RESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _RESPONSE_EXAMPLESENTRY._options = None
  _RESPONSE_EXAMPLESENTRY._serialized_options = b'8\001'
  _RESPONSE_EXTENSIONSENTRY._options = None
  _RESPONSE_EXTENSIONSENTRY._serialized_options = b'8\001'
  _INFO_EXTENSIONSENTRY._options = None
  _INFO_EXTENSIONSENTRY._serialized_options = b'8\001'
  _JSONSCHEMA_EXTENSIONSENTRY._options = None
  _JSONSCHEMA_EXTENSIONSENTRY._serialized_options = b'8\001'
  _TAG_EXTENSIONSENTRY._options = None
  _TAG_EXTENSIONSENTRY._serialized_options = b'8\001'
  _SECURITYDEFINITIONS_SECURITYENTRY._options = None
  _SECURITYDEFINITIONS_SECURITYENTRY._serialized_options = b'8\001'
  _SECURITYSCHEME_EXTENSIONSENTRY._options = None
  _SECURITYSCHEME_EXTENSIONSENTRY._serialized_options = b'8\001'
  _SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY._options = None
  _SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY._serialized_options = b'8\001'
  _SCOPES_SCOPEENTRY._options = None
  _SCOPES_SCOPEENTRY._serialized_options = b'8\001'
  _globals['_SCHEME']._serialized_start=7833
  _globals['_SCHEME']._serialized_end=7892
  _globals['_SWAGGER']._serialized_start=122
  _globals['_SWAGGER']._serialized_end=1197
  _globals['_SWAGGER_RESPONSESENTRY']._serialized_start=985
  _globals['_SWAGGER_RESPONSESENTRY']._serialized_end=1098
  _globals['_SWAGGER_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_SWAGGER_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_OPERATION']._serialized_start=1200
  _globals['_OPERATION']._serialized_end=2182
  _globals['_OPERATION_RESPONSESENTRY']._serialized_start=985
  _globals['_OPERATION_RESPONSESENTRY']._serialized_end=1098
  _globals['_OPERATION_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_OPERATION_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_PARAMETERS']._serialized_start=2184
  _globals['_PARAMETERS']._serialized_end=2282
  _globals['_HEADERPARAMETER']._serialized_start=2285
  _globals['_HEADERPARAMETER']._serialized_end=2576
  _globals['_HEADERPARAMETER_TYPE']._serialized_start=2495
  _globals['_HEADERPARAMETER_TYPE']._serialized_end=2564
  _globals['_HEADER']._serialized_start=2579
  _globals['_HEADER']._serialized_end=2795
  _globals['_RESPONSE']._serialized_start=2798
  _globals['_RESPONSE']._serialized_end=3464
  _globals['_RESPONSE_HEADERSENTRY']._serialized_start=3207
  _globals['_RESPONSE_HEADERSENTRY']._serialized_end=3316
  _globals['_RESPONSE_EXAMPLESENTRY']._serialized_start=3318
  _globals['_RESPONSE_EXAMPLESENTRY']._serialized_end=3377
  _globals['_RESPONSE_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_RESPONSE_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_INFO']._serialized_start=3467
  _globals['_INFO']._serialized_end=3937
  _globals['_INFO_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_INFO_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_CONTACT']._serialized_start=3939
  _globals['_CONTACT']._serialized_end=4008
  _globals['_LICENSE']._serialized_start=4010
  _globals['_LICENSE']._serialized_end=4057
  _globals['_EXTERNALDOCUMENTATION']._serialized_start=4059
  _globals['_EXTERNALDOCUMENTATION']._serialized_end=4134
  _globals['_SCHEMA']._serialized_start=4137
  _globals['_SCHEMA']._serialized_end=4435
  _globals['_JSONSCHEMA']._serialized_start=4438
  _globals['_JSONSCHEMA']._serialized_end=5805
  _globals['_JSONSCHEMA_FIELDCONFIGURATION']._serialized_start=5459
  _globals['_JSONSCHEMA_FIELDCONFIGURATION']._serialized_end=5519
  _globals['_JSONSCHEMA_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_JSONSCHEMA_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_JSONSCHEMA_JSONSCHEMASIMPLETYPES']._serialized_start=5608
  _globals['_JSONSCHEMA_JSONSCHEMASIMPLETYPES']._serialized_end=5727
  _globals['_TAG']._serialized_start=5808
  _globals['_TAG']._serialized_end=6153
  _globals['_TAG_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_TAG_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_SECURITYDEFINITIONS']._serialized_start=6156
  _globals['_SECURITYDEFINITIONS']._serialized_end=6403
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._serialized_start=6285
  _globals['_SECURITYDEFINITIONS_SECURITYENTRY']._serialized_end=6403
  _globals['_SECURITYSCHEME']._serialized_start=6406
  _globals['_SECURITYSCHEME']._serialized_end=7301
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._serialized_start=1100
  _globals['_SECURITYSCHEME_EXTENSIONSENTRY']._serialized_end=1185
  _globals['_SECURITYSCHEME_TYPE']._serialized_start=7067
  _globals['_SECURITYSCHEME_TYPE']._serialized_end=7142
  _globals['_SECURITYSCHEME_IN']._serialized_start=7144
  _globals['_SECURITYSCHEME_IN']._serialized_end=7193
  _globals['_SECURITYSCHEME_FLOW']._serialized_start=7195
  _globals['_SECURITYSCHEME_FLOW']._serialized_end=7301
  _globals['_SECURITYREQUIREMENT']._serialized_start=7304
  _globals['_SECURITYREQUIREMENT']._serialized_end=7678
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTVALUE']._serialized_start=7468
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTVALUE']._serialized_end=7516
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._serialized_start=7519
  _globals['_SECURITYREQUIREMENT_SECURITYREQUIREMENTENTRY']._serialized_end=7678
  _globals['_SCOPES']._serialized_start=7681
  _globals['_SCOPES']._serialized_end=7831
  _globals['_SCOPES_SCOPEENTRY']._serialized_start=7775
  _globals['_SCOPES_SCOPEENTRY']._serialized_end=7831
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/telemetry/v1/telemetry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cerbos/telemetry/v1/telemetry.proto\x12\x13\x63\x65rbos.telemetry.v1\x1a\x1egoogle/protobuf/duration.proto\"\xf6\x12\n\x0cServerLaunch\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12@\n\x06source\x18\x02 \x01(\x0b\x32(.cerbos.telemetry.v1.ServerLaunch.SourceR\x06source\x12\x46\n\x08\x66\x65\x61tures\x18\x03 \x01(\x0b\x32*.cerbos.telemetry.v1.ServerLaunch.FeaturesR\x08\x66\x65\x61tures\x12=\n\x05stats\x18\x04 \x01(\x0b\x32\'.cerbos.telemetry.v1.ServerLaunch.StatsR\x05stats\x1a\xa9\x01\n\x06\x43\x65rbos\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x1d\n\nbuild_date\x18\x03 \x01(\tR\tbuildDate\x12%\n\x0emodule_version\x18\x04 \x01(\tR\rmoduleVersion\x12\'\n\x0fmodule_checksum\x18\x05 \x01(\tR\x0emoduleChecksum\x1a\x89\x01\n\x06Source\x12@\n\x06\x63\x65rbos\x18\x01 \x01(\x0b\x32(.cerbos.telemetry.v1.ServerLaunch.CerbosR\x06\x63\x65rbos\x12\x0e\n\x02os\x18\x02 \x01(\tR\x02os\x12\x12\n\x04\x61rch\x18\x03 \x01(\tR\x04\x61rch\x12\x19\n\x08num_cpus\x18\x04 \x01(\rR\x07numCpus\x1a\x94\t\n\x08\x46\x65\x61tures\x12\x46\n\x05\x61udit\x18\x01 \x01(\x0b\x32\x30.cerbos.telemetry.v1.ServerLaunch.Features.AuditR\x05\x61udit\x12I\n\x06schema\x18\x02 \x01(\x0b\x32\x31.cerbos.telemetry.v1.ServerLaunch.Features.SchemaR\x06schema\x12P\n\tadmin_api\x18\x03 \x01(\x0b\x32\x33.cerbos.telemetry.v1.ServerLaunch.Features.AdminApiR\x08\x61\x64minApi\x12L\n\x07storage\x18\x04 \x01(\x0b\x32\x32.cerbos.telemetry.v1.ServerLaunch.Features.StorageR\x07storage\x1a;\n\x05\x41udit\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x18\n\x07\x62\x61\x63kend\x18\x02 \x01(\tR\x07\x62\x61\x63kend\x1a*\n\x06Schema\x12 \n\x0b\x65nforcement\x18\x01 \x01(\tR\x0b\x65nforcement\x1a$\n\x08\x41\x64minApi\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x1a\xc5\x05\n\x07Storage\x12\x16\n\x06\x64river\x18\x01 \x01(\tR\x06\x64river\x12M\n\x04\x64isk\x18\x02 \x01(\x0b\x32\x37.cerbos.telemetry.v1.ServerLaunch.Features.Storage.DiskH\x00R\x04\x64isk\x12J\n\x03git\x18\x03 \x01(\x0b\x32\x36.cerbos.telemetry.v1.ServerLaunch.Features.Storage.GitH\x00R\x03git\x12M\n\x04\x62lob\x18\x04 \x01(\x0b\x32\x37.cerbos.telemetry.v1.ServerLaunch.Features.Storage.BlobH\x00R\x04\x62lob\x12S\n\x06\x62undle\x18\x05 \x01(\x0b\x32\x39.cerbos.telemetry.v1.ServerLaunch.Features.Storage.BundleH\x00R\x06\x62undle\x1a\x1c\n\x04\x44isk\x12\x14\n\x05watch\x18\x01 \x01(\x08R\x05watch\x1au\n\x03Git\x12\x1a\n\x08protocol\x18\x01 \x01(\tR\x08protocol\x12\x12\n\x04\x61uth\x18\x02 \x01(\x08R\x04\x61uth\x12>\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cpollInterval\x1a\x62\n\x04\x42lob\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12>\n\rpoll_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cpollInterval\x1a\x61\n\x06\x42undle\x12\x15\n\x06pdp_id\x18\x01 \x01(\tR\x05pdpId\x12#\n\rbundle_source\x18\x02 \x01(\tR\x0c\x62undleSource\x12\x1b\n\tclient_id\x18\x03 \x01(\tR\x08\x63lientIdB\x07\n\x05store\x1a\xb3\x05\n\x05Stats\x12\x46\n\x06policy\x18\x01 \x01(\x0b\x32..cerbos.telemetry.v1.ServerLaunch.Stats.PolicyR\x06policy\x12\x46\n\x06schema\x18\x02 \x01(\x0b\x32..cerbos.telemetry.v1.ServerLaunch.Stats.SchemaR\x06schema\x1a\xf9\x03\n\x06Policy\x12O\n\x05\x63ount\x18\x01 \x03(\x0b\x32\x39.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.CountEntryR\x05\x63ount\x12\x66\n\x0e\x61vg_rule_count\x18\x02 \x03(\x0b\x32@.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.AvgRuleCountEntryR\x0c\x61vgRuleCount\x12u\n\x13\x61vg_condition_count\x18\x03 \x03(\x0b\x32\x45.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.AvgConditionCountEntryR\x11\x61vgConditionCount\x1a\x38\n\nCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\rR\x05value:\x02\x38\x01\x1a?\n\x11\x41vgRuleCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x44\n\x16\x41vgConditionCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x1e\n\x06Schema\x12\x14\n\x05\x63ount\x18\x01 \x01(\rR\x05\x63ount\"\x80\x01\n\nServerStop\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12%\n\x0erequests_total\x18\x03 \x01(\x04R\rrequestsTotal\"\xfe\x02\n\x05\x45vent\x12K\n\x0c\x61pi_activity\x18\x01 \x01(\x0b\x32&.cerbos.telemetry.v1.Event.ApiActivityH\x00R\x0b\x61piActivity\x1a\x33\n\tCountStat\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\x1a\xea\x01\n\x0b\x41piActivity\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12G\n\x0cmethod_calls\x18\x03 \x03(\x0b\x32$.cerbos.telemetry.v1.Event.CountStatR\x0bmethodCalls\x12\x45\n\x0buser_agents\x18\x04 \x03(\x0b\x32$.cerbos.telemetry.v1.Event.CountStatR\nuserAgentsB\x06\n\x04\x64\x61taB{\n\x1b\x64\x65v.cerbos.api.v1.telemetryZBgithub.com/cerbos/cerbos/api/genpb/cerbos/telemetry/v1;telemetryv1\xaa\x02\x17\x43\x65rbos.Api.V1.Telemetryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.telemetry.v1.telemetry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033dev.cerbos.api.v1.telemetryZBgithub.com/cerbos/cerbos/api/genpb/cerbos/telemetry/v1;telemetryv1\252\002\027Cerbos.Api.V1.Telemetry'
  _SERVERLAUNCH_STATS_POLICY_COUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_COUNTENTRY._serialized_options = b'8\001'
  _SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY._serialized_options = b'8\001'
  _SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY._serialized_options = b'8\001'
  _globals['_SERVERLAUNCH']._serialized_start=93
  _globals['_SERVERLAUNCH']._serialized_end=2515
  _globals['_SERVERLAUNCH_CERBOS']._serialized_start=337
  _globals['_SERVERLAUNCH_CERBOS']._serialized_end=506
  _globals['_SERVERLAUNCH_SOURCE']._serialized_start=509
  _globals['_SERVERLAUNCH_SOURCE']._serialized_end=646
  _globals['_SERVERLAUNCH_FEATURES']._serialized_start=649
  _globals['_SERVERLAUNCH_FEATURES']._serialized_end=1821
  _globals['_SERVERLAUNCH_FEATURES_AUDIT']._serialized_start=968
  _globals['_SERVERLAUNCH_FEATURES_AUDIT']._serialized_end=1027
  _globals['_SERVERLAUNCH_FEATURES_SCHEMA']._serialized_start=1029
  _globals['_SERVERLAUNCH_FEATURES_SCHEMA']._serialized_end=1071
  _globals['_SERVERLAUNCH_FEATURES_ADMINAPI']._serialized_start=1073
  _globals['_SERVERLAUNCH_FEATURES_ADMINAPI']._serialized_end=1109
  _globals['_SERVERLAUNCH_FEATURES_STORAGE']._serialized_start=1112
  _globals['_SERVERLAUNCH_FEATURES_STORAGE']._serialized_end=1821
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_DISK']._serialized_start=1466
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_DISK']._serialized_end=1494
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_GIT']._serialized_start=1496
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_GIT']._serialized_end=1613
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BLOB']._serialized_start=1615
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BLOB']._serialized_end=1713
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BUNDLE']._serialized_start=1715
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BUNDLE']._serialized_end=1812
  _globals['_SERVERLAUNCH_STATS']._serialized_start=1824
  _globals['_SERVERLAUNCH_STATS']._serialized_end=2515
  _globals['_SERVERLAUNCH_STATS_POLICY']._serialized_start=1978
  _globals['_SERVERLAUNCH_STATS_POLICY']._serialized_end=2483
  _globals['_SERVERLAUNCH_STATS_POLICY_COUNTENTRY']._serialized_start=2292
  _globals['_SERVERLAUNCH_STATS_POLICY_COUNTENTRY']._serialized_end=2348
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY']._serialized_start=2350
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY']._serialized_end=2413
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY']._serialized_start=2415
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY']._serialized_end=2483
  _globals['_SERVERLAUNCH_STATS_SCHEMA']._serialized_start=2485
  _globals['_SERVERLAUNCH_STATS_SCHEMA']._serialized_end=2515
  _globals['_SERVERSTOP']._serialized_start=2518
  _globals['_SERVERSTOP']._serialized_end=2646
  _globals['_EVENT']._serialized_start=2649
  _globals['_EVENT']._serialized_end=3031
  _globals['_EVENT_COUNTSTAT']._serialized_start=2735
  _globals['_EVENT_COUNTSTAT']._serialized_end=2786
  _globals['_EVENT_APIACTIVITY']._serialized_start=2789
  _globals['_EVENT_APIACTIVITY']._serialized_end=3023
# @@protoc_insertion_point(module_scope)



# Copyright 2021-2022 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

from cerbos.sdk._async._http import AsyncCerbosClient as AsyncCerbosClient
from cerbos.sdk._async._http import AsyncPrincipalContext as AsyncPrincipalContext
from cerbos.sdk._sync._http import CerbosClient as CerbosClient
from cerbos.sdk._sync._http import PrincipalContext as PrincipalContext

__all__ = [
    "AsyncCerbosClient",
    "AsyncPrincipalContext",
    "CerbosClient",
    "PrincipalContext",
]



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Effect(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    EFFECT_UNSPECIFIED: _ClassVar[Effect]
    EFFECT_ALLOW: _ClassVar[Effect]
    EFFECT_DENY: _ClassVar[Effect]
    EFFECT_NO_MATCH: _ClassVar[Effect]
EFFECT_UNSPECIFIED: Effect
EFFECT_ALLOW: Effect
EFFECT_DENY: Effect
EFFECT_NO_MATCH: Effect



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/response/v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.audit.v1 import audit_pb2 as cerbos_dot_audit_dot_v1_dot_audit__pb2
from cerbos.effect.v1 import effect_pb2 as cerbos_dot_effect_dot_v1_dot_effect__pb2
from cerbos.engine.v1 import engine_pb2 as cerbos_dot_engine_dot_v1_dot_engine__pb2
from cerbos.policy.v1 import policy_pb2 as cerbos_dot_policy_dot_v1_dot_policy__pb2
from cerbos.schema.v1 import schema_pb2 as cerbos_dot_schema_dot_v1_dot_schema__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cerbos/response/v1/response.proto\x12\x12\x63\x65rbos.response.v1\x1a\x1b\x63\x65rbos/audit/v1/audit.proto\x1a\x1d\x63\x65rbos/effect/v1/effect.proto\x1a\x1d\x63\x65rbos/engine/v1/engine.proto\x1a\x1d\x63\x65rbos/policy/v1/policy.proto\x1a\x1d\x63\x65rbos/schema/v1/schema.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\xb5\x08\n\x15PlanResourcesResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\x32\n\x06\x61\x63tion\x18\x02 \x01(\tB\x1a\x92\x41\x17\x32\x06\x41\x63tionJ\r\"view:public\"R\x06\x61\x63tion\x12\x8a\x01\n\rresource_kind\x18\x03 \x01(\tBe\x92\x41\x62\x32\x0eResource kind.J\x0e\"album:object\"\x8a\x01?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x0cresourceKind\x12J\n\x0epolicy_version\x18\x04 \x01(\tB#\x92\x41 2\x13The policy version.J\t\"default\"R\rpolicyVersion\x12J\n\x06\x66ilter\x18\x05 \x01(\x0b\x32%.cerbos.engine.v1.PlanResourcesFilterB\x0b\x92\x41\x08\x32\x06\x46ilterR\x06\x66ilter\x12\x7f\n\x04meta\x18\x06 \x01(\x0b\x32..cerbos.response.v1.PlanResourcesResponse.MetaB;\x92\x41\x38\x32\x36Optional metadata about the request evaluation processR\x04meta\x12\x90\x01\n\x11validation_errors\x18\x07 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1a\xff\x01\n\x04Meta\x12]\n\x0c\x66ilter_debug\x18\x01 \x01(\tB:\x92\x41\x37\x32\x35\x46ilter textual representation for debugging purposes.R\x0b\x66ilterDebug\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:)\x92\x41&\n$2\"Metadata about request evaluation.:<\x92\x41\x39\n725Resources query plan response for a set of resources.\"\xc8\x15\n\x18\x43heckResourceSetResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xdb\x02\n\x12resource_instances\x18\x02 \x03(\x0b\x32\x43.cerbos.response.v1.CheckResourceSetResponse.ResourceInstancesEntryB\xe6\x01\x92\x41\xe2\x01\x32KResults for each resource instance, keyed by the ID supplied in the requestJ\x92\x01{\"XX125\":{\"actions\":{\"view:*\":\"EFFECT_ALLOW\", \"comment\": \"EFFECT_ALLOW\"}}, \"XX225\":{\"actions\":{\"view:*\":\"EFFECT_DENY\", \"comment\": \"EFFECT_DENY\"}}}R\x11resourceInstances\x12\x82\x01\n\x04meta\x18\x03 \x01(\x0b\x32\x31.cerbos.response.v1.CheckResourceSetResponse.MetaB;\x92\x41\x38\x32\x36Optional metadata about the request evaluation processR\x04meta\x1a\x8b\x03\n\x0f\x41\x63tionEffectMap\x12\x8e\x01\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32I.cerbos.response.v1.CheckResourceSetResponse.ActionEffectMap.ActionsEntryB)\x92\x41&2$Mapping of each action to an effect.R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x02 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01\x1a\x89\x0c\n\x04Meta\x12\xcf\x03\n\x12resource_instances\x18\x01 \x03(\x0b\x32H.cerbos.response.v1.CheckResourceSetResponse.Meta.ResourceInstancesEntryB\xd5\x02\x92\x41\xd1\x02\x32\"Metadata about resource instances.J\xaa\x02{\"XX125\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}, \"XX225\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}}}R\x11resourceInstances\x1a\x88\x02\n\nEffectMeta\x12o\n\x0ematched_policy\x18\x01 \x01(\tBH\x92\x41\x45\x32+Policy that matched to produce this effect.J\x16\"album:object:default\"R\rmatchedPolicy\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:\x1a\x92\x41\x17\n\x15\x32\x13Name of the action.\x1a\xf3\x04\n\nActionMeta\x12\xa7\x02\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32I.cerbos.response.v1.CheckResourceSetResponse.Meta.ActionMeta.ActionsEntryB\xc1\x01\x92\x41\xbd\x01\x32OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}R\x07\x61\x63tions\x12\x83\x01\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tBK\x92\x41H2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x1ax\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.Meta.EffectMetaR\x05value:\x02\x38\x01:;\x92\x41\x38\n624Unique resource instance ID supplied in the request.\x1a\x82\x01\n\x16ResourceInstancesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.Meta.ActionMetaR\x05value:\x02\x38\x01:)\x92\x41&\n$2\"Metadata about request evaluation.\x1a\x82\x01\n\x16ResourceInstancesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.ActionEffectMapR\x05value:\x02\x38\x01:9\x92\x41\x36\n422Policy evaluation response for a set of resources.\"\xe5\x06\n\x1a\x43heckResourceBatchResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xb3\x01\n\x07results\x18\x02 \x03(\x0b\x32>.cerbos.response.v1.CheckResourceBatchResponse.ActionEffectMapBY\x92\x41V2\x18Result for each resourceJ:[{\"resourceId\":\"XX125\",\"actions\":{\"view\":\"EFFECT_ALLOW\"}}]R\x07results\x1a\xe2\x03\n\x0f\x41\x63tionEffectMap\x12:\n\x0bresource_id\x18\x01 \x01(\tB\x19\x92\x41\x16\x32\x0bResource IDJ\x07\"XX125\"R\nresourceId\x12\xa9\x01\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32K.cerbos.response.v1.CheckResourceBatchResponse.ActionEffectMap.ActionsEntryBB\x92\x41?2$Mapping of each action to an effect.J\x17{\"view\":\"EFFECT_ALLOW\"}R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01:;\x92\x41\x38\n624Policy evaluation response for a batch of resources.\"\xa6\x17\n\x16\x43heckResourcesResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xe3\x01\n\x07results\x18\x02 \x03(\x0b\x32\x36.cerbos.response.v1.CheckResourcesResponse.ResultEntryB\x90\x01\x92\x41\x8c\x01\x32\x18Result for each resourceJp[{\"resource\": {\"Id\":\"XX125\", \"kind\":\"album:object\"}, \"actions\":{\"view\":\"EFFECT_ALLOW\",\"comment\":\"EFFECT_DENY\"}}]R\x07results\x1a\x80\x14\n\x0bResultEntry\x12[\n\x08resource\x18\x01 \x01(\x0b\x32?.cerbos.response.v1.CheckResourcesResponse.ResultEntry.ResourceR\x08resource\x12\xa1\x01\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x43.cerbos.response.v1.CheckResourcesResponse.ResultEntry.ActionsEntryBB\x92\x41?2$Mapping of each action to an effect.J\x17{\"view\":\"EFFECT_ALLOW\"}R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x12\x98\x02\n\x04meta\x18\x04 \x01(\x0b\x32;.cerbos.response.v1.CheckResourcesResponse.ResultEntry.MetaB\xc6\x01\x92\x41\xc2\x01\x32 Metadata about policy evaluationJ\x9d\x01{\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}R\x04meta\x12\xf6\x01\n\x07outputs\x18\x05 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryB\xbc\x01\x92\x41\xb8\x01\x32,Output for each rule with outputs configuredJ\x87\x01[{\"src\": \"resource.expense.v1/acme#rule-001\", \"val\": \"view_allowed:alice\"}, {\"src\": \"resource.expense.v1/acme#rule-002\", \"val\": \"foo\"}]R\x07outputs\x1a\xff\x04\n\x08Resource\x12\x39\n\x02id\x18\x01 \x01(\tB)\x92\x41&2\x1bID of the resource instanceJ\x07\"XX125\"R\x02id\x12\x93\x01\n\x04kind\x18\x02 \x01(\tB\x7f\x92\x41|2)Name of the resource kind being accessed.J\r\"album:photo\"\x8a\x01?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x04kind\x12\xc5\x01\n\x0epolicy_version\x18\x03 \x01(\tB\x9d\x01\x92\x41\x99\x01\x32|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\x8a\x01\r^[[:word:]]*$R\rpolicyVersion\x12\xd9\x01\n\x05scope\x18\x04 \x01(\tB\xc2\x01\x92\x41\xbe\x01\x32}A dot-separated scope that describes the hierarchy this resource belongs to. This is used for determining policy inheritance.J\x0b\"acme.corp\"\x8a\x01/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x1a\xf0\x06\n\x04Meta\x12\xa6\x02\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32H.cerbos.response.v1.CheckResourcesResponse.ResultEntry.Meta.ActionsEntryB\xc1\x01\x92\x41\xbd\x01\x32OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}R\x07\x61\x63tions\x12\x83\x01\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tBK\x92\x41H2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x1a\x88\x02\n\nEffectMeta\x12o\n\x0ematched_policy\x18\x01 \x01(\tBH\x92\x41\x45\x32+Policy that matched to produce this effect.J\x16\"album:object:default\"R\rmatchedPolicy\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:\x1a\x92\x41\x17\n\x15\x32\x13Name of the action.\x1a\x82\x01\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\\\n\x05value\x18\x02 \x01(\x0b\x32\x46.cerbos.response.v1.CheckResourcesResponse.ResultEntry.Meta.EffectMetaR\x05value:\x02\x38\x01:)\x92\x41&\n$2\"Metadata about request evaluation.\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01:2\x92\x41/\n-2+Response from the check resources API call.\"\xa7\x01\n\x11PlaygroundFailure\x12\x43\n\x06\x65rrors\x18\x01 \x03(\x0b\x32+.cerbos.response.v1.PlaygroundFailure.ErrorR\x06\x65rrors\x1a\x31\n\x05\x45rror\x12\x12\n\x04\x66ile\x18\x01 \x01(\tR\x04\x66ile\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror:\x1a\x92\x41\x17\n\x15\x32\x13Playground response\"\xe8\x01\n\x1aPlaygroundValidateResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12\x32\n\x07success\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07success:#\x92\x41 \n\x1e\x32\x1cPlayground validate responseB\t\n\x07outcome\"\xc8\x02\n\x16PlaygroundTestResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12R\n\x07success\x18\x03 \x01(\x0b\x32\x36.cerbos.response.v1.PlaygroundTestResponse.TestResultsH\x00R\x07success\x1a\x46\n\x0bTestResults\x12\x37\n\x07results\x18\x01 \x01(\x0b\x32\x1d.cerbos.policy.v1.TestResultsR\x07results:\x1f\x92\x41\x1c\n\x1a\x32\x18Playground test responseB\t\n\x07outcome\"\xb9\x06\n\x1aPlaygroundEvaluateResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12Y\n\x07success\x18\x03 \x01(\x0b\x32=.cerbos.response.v1.PlaygroundEvaluateResponse.EvalResultListH\x00R\x07success\x1a\xfe\x01\n\nEvalResult\x12\x16\n\x06\x61\x63tion\x18\x01 \x01(\tR\x06\x61\x63tion\x12\x30\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x06\x65\x66\x66\x65\x63t\x12\x16\n\x06policy\x18\x03 \x01(\tR\x06policy\x12:\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x04 \x03(\tB\x02\x18\x01R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x12R\n\x11validation_errors\x18\x05 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB\x02\x18\x01R\x10validationErrors\x1a\xa6\x02\n\x0e\x45valResultList\x12S\n\x07results\x18\x01 \x03(\x0b\x32\x39.cerbos.response.v1.PlaygroundEvaluateResponse.EvalResultR\x07results\x12\x36\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tR\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x12N\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorR\x10validationErrors\x12\x37\n\x07outputs\x18\x04 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryR\x07outputs:#\x92\x41 \n\x1e\x32\x1cPlayground evaluate responseB\t\n\x07outcome\"\x9b\x04\n\x17PlaygroundProxyResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12\\\n\x12\x63heck_resource_set\x18\x03 \x01(\x0b\x32,.cerbos.response.v1.CheckResourceSetResponseH\x00R\x10\x63heckResourceSet\x12\x62\n\x14\x63heck_resource_batch\x18\x04 \x01(\x0b\x32..cerbos.response.v1.CheckResourceBatchResponseH\x00R\x12\x63heckResourceBatch\x12R\n\x0eplan_resources\x18\x05 \x01(\x0b\x32).cerbos.response.v1.PlanResourcesResponseH\x00R\rplanResources\x12U\n\x0f\x63heck_resources\x18\x06 \x01(\x0b\x32*.cerbos.response.v1.CheckResourcesResponseH\x00R\x0e\x63heckResources: \x92\x41\x1d\n\x1b\x32\x19Playground proxy responseB\t\n\x07outcome\"p\n\x19\x41\x64\x64OrUpdatePolicyResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success:!\x92\x41\x1e\n\x1c\x32\x1a\x41\x64\x64/update policy response\"\xe0\x01\n\x1bListAuditLogEntriesResponse\x12K\n\x10\x61\x63\x63\x65ss_log_entry\x18\x01 \x01(\x0b\x32\x1f.cerbos.audit.v1.AccessLogEntryH\x00R\x0e\x61\x63\x63\x65ssLogEntry\x12Q\n\x12\x64\x65\x63ision_log_entry\x18\x02 \x01(\x0b\x32!.cerbos.audit.v1.DecisionLogEntryH\x00R\x10\x64\x65\x63isionLogEntry:\x18\x92\x41\x15\n\x13\x32\x11\x41udit log stream.B\x07\n\x05\x65ntry\"\x82\x01\n\x12ServerInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x1d\n\nbuild_date\x18\x03 \x01(\tR\tbuildDate:\x1b\x92\x41\x18\n\x16\x32\x14Server info response\"j\n\x14ListPoliciesResponse\x12\x1d\n\npolicy_ids\x18\x01 \x03(\tR\tpolicyIds:3\x92\x41\x30\n.2,List of policies stored in the Cerbos server\"e\n\x11GetPolicyResponse\x12\x34\n\x08policies\x18\x01 \x03(\x0b\x32\x18.cerbos.policy.v1.PolicyR\x08policies:\x1a\x92\x41\x17\n\x15\x32\x13Get policy response\"d\n\x15\x44isablePolicyResponse\x12+\n\x11\x64isabled_policies\x18\x01 \x01(\rR\x10\x64isabledPolicies:\x1e\x92\x41\x1b\n\x19\x32\x17\x44isable policy response\"`\n\x14\x45nablePolicyResponse\x12)\n\x10\x65nabled_policies\x18\x01 \x01(\rR\x0f\x65nabledPolicies:\x1d\x92\x41\x1a\n\x18\x32\x16\x45nable policy response\">\n\x19\x41\x64\x64OrUpdateSchemaResponse:!\x92\x41\x1e\n\x1c\x32\x1a\x41\x64\x64/update schema response\"U\n\x13ListSchemasResponse\x12\x1d\n\nschema_ids\x18\x01 \x03(\tR\tschemaIds:\x1f\x92\x41\x1c\n\x1a\x32\x18List schema ids response\"f\n\x11GetSchemaResponse\x12\x32\n\x07schemas\x18\x01 \x03(\x0b\x32\x18.cerbos.schema.v1.SchemaR\x07schemas:\x1d\x92\x41\x1a\n\x18\x32\x16Get schema(s) response\"a\n\x14\x44\x65leteSchemaResponse\x12\'\n\x0f\x64\x65leted_schemas\x18\x01 \x01(\rR\x0e\x64\x65letedSchemas: \x92\x41\x1d\n\x1b\x32\x19\x44\x65lete schema(s) response\"3\n\x13ReloadStoreResponse:\x1c\x92\x41\x19\n\x17\x32\x15Reload store responseBw\n\x1a\x64\x65v.cerbos.api.v1.responseZ@github.com/cerbos/cerbos/api/genpb/cerbos/response/v1;responsev1\xaa\x02\x16\x43\x65rbos.Api.V1.Responseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.response.v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032dev.cerbos.api.v1.responseZ@github.com/cerbos/cerbos/api/genpb/cerbos/response/v1;responsev1\252\002\026Cerbos.Api.V1.Response'
  _PLANRESOURCESRESPONSE_META.fields_by_name['filter_debug']._options = None
  _PLANRESOURCESRESPONSE_META.fields_by_name['filter_debug']._serialized_options = b'\222A725Filter textual representation for debugging purposes.'
  _PLANRESOURCESRESPONSE_META.fields_by_name['matched_scope']._options = None
  _PLANRESOURCESRESPONSE_META.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _PLANRESOURCESRESPONSE_META._options = None
  _PLANRESOURCESRESPONSE_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _PLANRESOURCESRESPONSE.fields_by_name['request_id']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _PLANRESOURCESRESPONSE.fields_by_name['action']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['action']._serialized_options = b'\222A\0272\006ActionJ\r\"view:public\"'
  _PLANRESOURCESRESPONSE.fields_by_name['resource_kind']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['resource_kind']._serialized_options = b'\222Ab2\016Resource kind.J\016\"album:object\"\212\001?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _PLANRESOURCESRESPONSE.fields_by_name['policy_version']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['policy_version']._serialized_options = b'\222A 2\023The policy version.J\t\"default\"'
  _PLANRESOURCESRESPONSE.fields_by_name['filter']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['filter']._serialized_options = b'\222A\0102\006Filter'
  _PLANRESOURCESRESPONSE.fields_by_name['meta']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['meta']._serialized_options = b'\222A826Optional metadata about the request evaluation process'
  _PLANRESOURCESRESPONSE.fields_by_name['validation_errors']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _PLANRESOURCESRESPONSE._options = None
  _PLANRESOURCESRESPONSE._serialized_options = b'\222A9\n725Resources query plan response for a set of resources.'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._serialized_options = b'\222A&2$Mapping of each action to an effect.'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_policy']._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_policy']._serialized_options = b'\222AE2+Policy that matched to produce this effect.J\026\"album:object:default\"'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_scope']._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA._serialized_options = b'\222A\027\n\0252\023Name of the action.'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['actions']._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['actions']._serialized_options = b'\222A\275\0012OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['effective_derived_roles']._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['effective_derived_roles']._serialized_options = b'\222AH2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA._serialized_options = b'\222A8\n624Unique resource instance ID supplied in the request.'
  _CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY._options = None
  _CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_META.fields_by_name['resource_instances']._options = None
  _CHECKRESOURCESETRESPONSE_META.fields_by_name['resource_instances']._serialized_options = b'\222A\321\0022\"Metadata about resource instances.J\252\002{\"XX125\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}, \"XX225\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}}}'
  _CHECKRESOURCESETRESPONSE_META._options = None
  _CHECKRESOURCESETRESPONSE_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY._options = None
  _CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESETRESPONSE.fields_by_name['resource_instances']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['resource_instances']._serialized_options = b'\222A\342\0012KResults for each resource instance, keyed by the ID supplied in the requestJ\222\001{\"XX125\":{\"actions\":{\"view:*\":\"EFFECT_ALLOW\", \"comment\": \"EFFECT_ALLOW\"}}, \"XX225\":{\"actions\":{\"view:*\":\"EFFECT_DENY\", \"comment\": \"EFFECT_DENY\"}}}'
  _CHECKRESOURCESETRESPONSE.fields_by_name['meta']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['meta']._serialized_options = b'\222A826Optional metadata about the request evaluation process'
  _CHECKRESOURCESETRESPONSE._options = None
  _CHECKRESOURCESETRESPONSE._serialized_options = b'\222A6\n422Policy evaluation response for a set of resources.'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['resource_id']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['resource_id']._serialized_options = b'\222A\0262\013Resource IDJ\007\"XX125\"'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._serialized_options = b'\222A?2$Mapping of each action to an effect.J\027{\"view\":\"EFFECT_ALLOW\"}'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['results']._options = None
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['results']._serialized_options = b'\222AV2\030Result for each resourceJ:[{\"resourceId\":\"XX125\",\"actions\":{\"view\":\"EFFECT_ALLOW\"}}]'
  _CHECKRESOURCEBATCHRESPONSE._options = None
  _CHECKRESOURCEBATCHRESPONSE._serialized_options = b'\222A8\n624Policy evaluation response for a batch of resources.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['id']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['id']._serialized_options = b'\222A&2\033ID of the resource instanceJ\007\"XX125\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['kind']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['kind']._serialized_options = b'\222A|2)Name of the resource kind being accessed.J\r\"album:photo\"\212\001?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['policy_version']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['policy_version']._serialized_options = b'\222A\231\0012|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\212\001\r^[[:word:]]*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['scope']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['scope']._serialized_options = b'\222A\276\0012}A dot-separated scope that describes the hierarchy this resource belongs to. This is used for determining policy inheritance.J\013\"acme.corp\"\212\001/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_policy']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_policy']._serialized_options = b'\222AE2+Policy that matched to produce this effect.J\026\"album:object:default\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_scope']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA._serialized_options = b'\222A\027\n\0252\023Name of the action.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['actions']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['actions']._serialized_options = b'\222A\275\0012OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['effective_derived_roles']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['effective_derived_roles']._serialized_options = b'\222AH2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['actions']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['actions']._serialized_options = b'\222A?2$Mapping of each action to an effect.J\027{\"view\":\"EFFECT_ALLOW\"}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['meta']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['meta']._serialized_options = b'\222A\302\0012 Metadata about policy evaluationJ\235\001{\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['outputs']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['outputs']._serialized_options = b'\222A\270\0012,Output for each rule with outputs configuredJ\207\001[{\"src\": \"resource.expense.v1/acme#rule-001\", \"val\": \"view_allowed:alice\"}, {\"src\": \"resource.expense.v1/acme#rule-002\", \"val\": \"foo\"}]'
  _CHECKRESOURCESRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCESRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESRESPONSE.fields_by_name['results']._options = None
  _CHECKRESOURCESRESPONSE.fields_by_name['results']._serialized_options = b'\222A\214\0012\030Result for each resourceJp[{\"resource\": {\"Id\":\"XX125\", \"kind\":\"album:object\"}, \"actions\":{\"view\":\"EFFECT_ALLOW\",\"comment\":\"EFFECT_DENY\"}}]'
  _CHECKRESOURCESRESPONSE._options = None
  _CHECKRESOURCESRESPONSE._serialized_options = b'\222A/\n-2+Response from the check resources API call.'
  _PLAYGROUNDFAILURE._options = None
  _PLAYGROUNDFAILURE._serialized_options = b'\222A\027\n\0252\023Playground response'
  _PLAYGROUNDVALIDATERESPONSE._options = None
  _PLAYGROUNDVALIDATERESPONSE._serialized_options = b'\222A \n\0362\034Playground validate response'
  _PLAYGROUNDTESTRESPONSE._options = None
  _PLAYGROUNDTESTRESPONSE._serialized_options = b'\222A\034\n\0322\030Playground test response'
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['effective_derived_roles']._options = None
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['effective_derived_roles']._serialized_options = b'\030\001'
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['validation_errors']._options = None
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['validation_errors']._serialized_options = b'\030\001'
  _PLAYGROUNDEVALUATERESPONSE._options = None
  _PLAYGROUNDEVALUATERESPONSE._serialized_options = b'\222A \n\0362\034Playground evaluate response'
  _PLAYGROUNDPROXYRESPONSE._options = None
  _PLAYGROUNDPROXYRESPONSE._serialized_options = b'\222A\035\n\0332\031Playground proxy response'
  _ADDORUPDATEPOLICYRESPONSE._options = None
  _ADDORUPDATEPOLICYRESPONSE._serialized_options = b'\222A\036\n\0342\032Add/update policy response'
  _LISTAUDITLOGENTRIESRESPONSE._options = None
  _LISTAUDITLOGENTRIESRESPONSE._serialized_options = b'\222A\025\n\0232\021Audit log stream.'
  _SERVERINFORESPONSE._options = None
  _SERVERINFORESPONSE._serialized_options = b'\222A\030\n\0262\024Server info response'
  _LISTPOLICIESRESPONSE._options = None
  _LISTPOLICIESRESPONSE._serialized_options = b'\222A0\n.2,List of policies stored in the Cerbos server'
  _GETPOLICYRESPONSE._options = None
  _GETPOLICYRESPONSE._serialized_options = b'\222A\027\n\0252\023Get policy response'
  _DISABLEPOLICYRESPONSE._options = None
  _DISABLEPOLICYRESPONSE._serialized_options = b'\222A\033\n\0312\027Disable policy response'
  _ENABLEPOLICYRESPONSE._options = None
  _ENABLEPOLICYRESPONSE._serialized_options = b'\222A\032\n\0302\026Enable policy response'
  _ADDORUPDATESCHEMARESPONSE._options = None
  _ADDORUPDATESCHEMARESPONSE._serialized_options = b'\222A\036\n\0342\032Add/update schema response'
  _LISTSCHEMASRESPONSE._options = None
  _LISTSCHEMASRESPONSE._serialized_options = b'\222A\034\n\0322\030List schema ids response'
  _GETSCHEMARESPONSE._options = None
  _GETSCHEMARESPONSE._serialized_options = b'\222A\032\n\0302\026Get schema(s) response'
  _DELETESCHEMARESPONSE._options = None
  _DELETESCHEMARESPONSE._serialized_options = b'\222A\035\n\0332\031Delete schema(s) response'
  _RELOADSTORERESPONSE._options = None
  _RELOADSTORERESPONSE._serialized_options = b'\222A\031\n\0272\025Reload store response'
  _globals['_PLANRESOURCESRESPONSE']._serialized_start=288
  _globals['_PLANRESOURCESRESPONSE']._serialized_end=1365
  _globals['_PLANRESOURCESRESPONSE_META']._serialized_start=1048
  _globals['_PLANRESOURCESRESPONSE_META']._serialized_end=1303
  _globals['_CHECKRESOURCESETRESPONSE']._serialized_start=1368
  _globals['_CHECKRESOURCESETRESPONSE']._serialized_end=4128
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP']._serialized_start=1993
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP']._serialized_end=2388
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_end=2388
  _globals['_CHECKRESOURCESETRESPONSE_META']._serialized_start=2391
  _globals['_CHECKRESOURCESETRESPONSE_META']._serialized_end=3936
  _globals['_CHECKRESOURCESETRESPONSE_META_EFFECTMETA']._serialized_start=2866
  _globals['_CHECKRESOURCESETRESPONSE_META_EFFECTMETA']._serialized_end=3130
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA']._serialized_start=3133
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA']._serialized_end=3760
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY']._serialized_start=3579
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY']._serialized_end=3699
  _globals['_CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY']._serialized_start=3763
  _globals['_CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY']._serialized_end=3893
  _globals['_CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY']._serialized_start=3939
  _globals['_CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY']._serialized_end=4069
  _globals['_CHECKRESOURCEBATCHRESPONSE']._serialized_start=4131
  _globals['_CHECKRESOURCEBATCHRESPONSE']._serialized_end=5000
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP']._serialized_start=4457
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP']._serialized_end=4939
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_end=2388
  _globals['_CHECKRESOURCESRESPONSE']._serialized_start=5003
  _globals['_CHECKRESOURCESRESPONSE']._serialized_end=7985
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY']._serialized_start=5373
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY']._serialized_end=7933
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE']._serialized_start=6325
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE']._serialized_end=6964
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META']._serialized_start=6967
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META']._serialized_end=7847
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA']._serialized_start=2866
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA']._serialized_end=3130
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY']._serialized_start=7674
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY']._serialized_end=7804
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY']._serialized_end=2388
  _globals['_PLAYGROUNDFAILURE']._serialized_start=7988
  _globals['_PLAYGROUNDFAILURE']._serialized_end=8155
  _globals['_PLAYGROUNDFAILURE_ERROR']._serialized_start=8078
  _globals['_PLAYGROUNDFAILURE_ERROR']._serialized_end=8127
  _globals['_PLAYGROUNDVALIDATERESPONSE']._serialized_start=8158
  _globals['_PLAYGROUNDVALIDATERESPONSE']._serialized_end=8390
  _globals['_PLAYGROUNDTESTRESPONSE']._serialized_start=8393
  _globals['_PLAYGROUNDTESTRESPONSE']._serialized_end=8721
  _globals['_PLAYGROUNDTESTRESPONSE_TESTRESULTS']._serialized_start=8607
  _globals['_PLAYGROUNDTESTRESPONSE_TESTRESULTS']._serialized_end=8677
  _globals['_PLAYGROUNDEVALUATERESPONSE']._serialized_start=8724
  _globals['_PLAYGROUNDEVALUATERESPONSE']._serialized_end=9549
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULT']._serialized_start=8950
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULT']._serialized_end=9204
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULTLIST']._serialized_start=9207
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULTLIST']._serialized_end=9501
  _globals['_PLAYGROUNDPROXYRESPONSE']._serialized_start=9552
  _globals['_PLAYGROUNDPROXYRESPONSE']._serialized_end=10091
  _globals['_ADDORUPDATEPOLICYRESPONSE']._serialized_start=10093
  _globals['_ADDORUPDATEPOLICYRESPONSE']._serialized_end=10205
  _globals['_LISTAUDITLOGENTRIESRESPONSE']._serialized_start=10208
  _globals['_LISTAUDITLOGENTRIESRESPONSE']._serialized_end=10432
  _globals['_SERVERINFORESPONSE']._serialized_start=10435
  _globals['_SERVERINFORESPONSE']._serialized_end=10565
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=10567
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=10673
  _globals['_GETPOLICYRESPONSE']._serialized_start=10675
  _globals['_GETPOLICYRESPONSE']._serialized_end=10776
  _globals['_DISABLEPOLICYRESPONSE']._serialized_start=10778
  _globals['_DISABLEPOLICYRESPONSE']._serialized_end=10878
  _globals['_ENABLEPOLICYRESPONSE']._serialized_start=10880
  _globals['_ENABLEPOLICYRESPONSE']._serialized_end=10976
  _globals['_ADDORUPDATESCHEMARESPONSE']._serialized_start=10978
  _globals['_ADDORUPDATESCHEMARESPONSE']._serialized_end=11040
  _globals['_LISTSCHEMASRESPONSE']._serialized_start=11042
  _globals['_LISTSCHEMASRESPONSE']._serialized_end=11127
  _globals['_GETSCHEMARESPONSE']._serialized_start=11129
  _globals['_GETSCHEMARESPONSE']._serialized_end=11231
  _globals['_DELETESCHEMARESPONSE']._serialized_start=11233
  _globals['_DELETESCHEMARESPONSE']._serialized_end=11330
  _globals['_RELOADSTORERESPONSE']._serialized_start=11332
  _globals['_RELOADSTORERESPONSE']._serialized_end=11383
# @@protoc_insertion_point(module_scope)



from cerbos.engine.v1 import engine_pb2 as _engine_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccessLogEntry(_message.Message):
    __slots__ = ["call_id", "timestamp", "peer", "metadata", "method", "status_code"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: MetaValues
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MetaValues, _Mapping]] = ...) -> None: ...
    CALL_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    PEER_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    call_id: str
    timestamp: _timestamp_pb2.Timestamp
    peer: Peer
    metadata: _containers.MessageMap[str, MetaValues]
    method: str
    status_code: int
    def __init__(self, call_id: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., peer: _Optional[_Union[Peer, _Mapping]] = ..., metadata: _Optional[_Mapping[str, MetaValues]] = ..., method: _Optional[str] = ..., status_code: _Optional[int] = ...) -> None: ...

class DecisionLogEntry(_message.Message):
    __slots__ = ["call_id", "timestamp", "peer", "inputs", "outputs", "error", "check_resources", "plan_resources", "metadata"]
    class CheckResources(_message.Message):
        __slots__ = ["inputs", "outputs", "error"]
        INPUTS_FIELD_NUMBER: _ClassVar[int]
        OUTPUTS_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        inputs: _containers.RepeatedCompositeFieldContainer[_engine_pb2.CheckInput]
        outputs: _containers.RepeatedCompositeFieldContainer[_engine_pb2.CheckOutput]
        error: str
        def __init__(self, inputs: _Optional[_Iterable[_Union[_engine_pb2.CheckInput, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[_engine_pb2.CheckOutput, _Mapping]]] = ..., error: _Optional[str] = ...) -> None: ...
    class PlanResources(_message.Message):
        __slots__ = ["input", "output", "error"]
        INPUT_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        input: _engine_pb2.PlanResourcesInput
        output: _engine_pb2.PlanResourcesOutput
        error: str
        def __init__(self, input: _Optional[_Union[_engine_pb2.PlanResourcesInput, _Mapping]] = ..., output: _Optional[_Union[_engine_pb2.PlanResourcesOutput, _Mapping]] = ..., error: _Optional[str] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: MetaValues
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MetaValues, _Mapping]] = ...) -> None: ...
    CALL_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    PEER_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    CHECK_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    PLAN_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    call_id: str
    timestamp: _timestamp_pb2.Timestamp
    peer: Peer
    inputs: _containers.RepeatedCompositeFieldContainer[_engine_pb2.CheckInput]
    outputs: _containers.RepeatedCompositeFieldContainer[_engine_pb2.CheckOutput]
    error: str
    check_resources: DecisionLogEntry.CheckResources
    plan_resources: DecisionLogEntry.PlanResources
    metadata: _containers.MessageMap[str, MetaValues]
    def __init__(self, call_id: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., peer: _Optional[_Union[Peer, _Mapping]] = ..., inputs: _Optional[_Iterable[_Union[_engine_pb2.CheckInput, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[_engine_pb2.CheckOutput, _Mapping]]] = ..., error: _Optional[str] = ..., check_resources: _Optional[_Union[DecisionLogEntry.CheckResources, _Mapping]] = ..., plan_resources: _Optional[_Union[DecisionLogEntry.PlanResources, _Mapping]] = ..., metadata: _Optional[_Mapping[str, MetaValues]] = ...) -> None: ...

class MetaValues(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...

class Peer(_message.Message):
    __slots__ = ["address", "auth_info", "user_agent", "forwarded_for"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    FORWARDED_FOR_FIELD_NUMBER: _ClassVar[int]
    address: str
    auth_info: str
    user_agent: str
    forwarded_for: str
    def __init__(self, address: _Optional[str] = ..., auth_info: _Optional[str] = ..., user_agent: _Optional[str] = ..., forwarded_for: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/svc/v1/svc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.request.v1 import request_pb2 as cerbos_dot_request_dot_v1_dot_request__pb2
from cerbos.response.v1 import response_pb2 as cerbos_dot_response_dot_v1_dot_response__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63\x65rbos/svc/v1/svc.proto\x12\rcerbos.svc.v1\x1a\x1f\x63\x65rbos/request/v1/request.proto\x1a!cerbos/response/v1/response.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd6\n\n\rCerbosService\x12\xa7\x02\n\x10\x43heckResourceSet\x12*.cerbos.request.v1.CheckResourceSetRequest\x1a,.cerbos.response.v1.CheckResourceSetResponse\"\xb8\x01\x92\x41\x9f\x01\x12\x05\x43heck\x1a\x93\x01[Deprecated: Use CheckResources API instead] Check whether a principal has permissions to perform the given actions on a set of resource instances.X\x01\x82\xd3\xe4\x93\x02\x0f\"\n/api/check:\x01*\x12\xb6\x02\n\x12\x43heckResourceBatch\x12,.cerbos.request.v1.CheckResourceBatchRequest\x1a..cerbos.response.v1.CheckResourceBatchResponse\"\xc1\x01\x92\x41\x99\x01\x12\x14\x43heck resource batch\x1a\x7f[Deprecated: Use CheckResources API instead] Check a principal\'s permissions to a batch of heterogeneous resources and actions.X\x01\x82\xd3\xe4\x93\x02\x1e\"\x19/api/check_resource_batch:\x01*\x12\xf0\x01\n\x0e\x43heckResources\x12(.cerbos.request.v1.CheckResourcesRequest\x1a*.cerbos.response.v1.CheckResourcesResponse\"\x87\x01\x92\x41\x65\x12\x0f\x43heck resources\x1aRCheck a principal\'s permissions to a batch of heterogeneous resources and actions.\x82\xd3\xe4\x93\x02\x19\"\x14/api/check/resources:\x01*\x12\xc5\x01\n\nServerInfo\x12$.cerbos.request.v1.ServerInfoRequest\x1a&.cerbos.response.v1.ServerInfoResponse\"i\x92\x41N\x12\x16Get server information\x1a\x34Get information about the server e.g. server version\x82\xd3\xe4\x93\x02\x12\x12\x10/api/server_info\x12\x83\x02\n\rPlanResources\x12\'.cerbos.request.v1.PlanResourcesRequest\x1a).cerbos.response.v1.PlanResourcesResponse\"\x9d\x01\x92\x41|\x12\x0ePlan resources\x1ajProduce a query plan with conditions that must be satisfied for accessing a set of instances of a resource\x82\xd3\xe4\x93\x02\x18\"\x13/api/plan/resources:\x01*\x1a!\x92\x41\x1e\x12\x1c\x43\x65rbos Policy Decision Point2\xc5\x0f\n\x12\x43\x65rbosAdminService\x12\xc9\x01\n\x11\x41\x64\x64OrUpdatePolicy\x12+.cerbos.request.v1.AddOrUpdatePolicyRequest\x1a-.cerbos.response.v1.AddOrUpdatePolicyResponse\"X\x92\x41)\x12\x16\x41\x64\x64 or update policiesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02&\"\r/admin/policy:\x01*Z\x12\x1a\r/admin/policy:\x01*\x12\x9c\x01\n\x0cListPolicies\x12&.cerbos.request.v1.ListPoliciesRequest\x1a(.cerbos.response.v1.ListPoliciesResponse\":\x92\x41 \x12\rList policiesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x11\x12\x0f/admin/policies\x12\x8e\x01\n\tGetPolicy\x12#.cerbos.request.v1.GetPolicyRequest\x1a%.cerbos.response.v1.GetPolicyResponse\"5\x92\x41\x1d\x12\nGet policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f\x12\r/admin/policy\x12\xd3\x01\n\rDisablePolicy\x12\'.cerbos.request.v1.DisablePolicyRequest\x1a).cerbos.response.v1.DisablePolicyResponse\"n\x92\x41!\x12\x0e\x44isable policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x44\"\x15/admin/policy/disableZ\x1a\x1a\x15/admin/policy/disable:\x01*Z\x0f*\r/admin/policy\x12\xbc\x01\n\x0c\x45nablePolicy\x12&.cerbos.request.v1.EnablePolicyRequest\x1a(.cerbos.response.v1.EnablePolicyResponse\"Z\x92\x41 \x12\rEnable policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x31\"\x14/admin/policy/enableZ\x19\x1a\x14/admin/policy/enable:\x01*\x12\xc8\x01\n\x13ListAuditLogEntries\x12-.cerbos.request.v1.ListAuditLogEntriesRequest\x1a/.cerbos.response.v1.ListAuditLogEntriesResponse\"O\x92\x41)\x12\x16List audit log entriesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x1d\x12\x1b/admin/auditlog/list/{kind}0\x01\x12\xc7\x01\n\x11\x41\x64\x64OrUpdateSchema\x12+.cerbos.request.v1.AddOrUpdateSchemaRequest\x1a-.cerbos.response.v1.AddOrUpdateSchemaResponse\"V\x92\x41\'\x12\x14\x41\x64\x64 or update schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02&\"\r/admin/schema:\x01*Z\x12\x1a\r/admin/schema:\x01*\x12\x97\x01\n\x0bListSchemas\x12%.cerbos.request.v1.ListSchemasRequest\x1a\'.cerbos.response.v1.ListSchemasResponse\"8\x92\x41\x1f\x12\x0cList schemasb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x10\x12\x0e/admin/schemas\x12\x8e\x01\n\tGetSchema\x12#.cerbos.request.v1.GetSchemaRequest\x1a%.cerbos.response.v1.GetSchemaResponse\"5\x92\x41\x1d\x12\nGet schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f\x12\r/admin/schema\x12\x9a\x01\n\x0c\x44\x65leteSchema\x12&.cerbos.request.v1.DeleteSchemaRequest\x1a(.cerbos.response.v1.DeleteSchemaResponse\"8\x92\x41 \x12\rDelete schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f*\r/admin/schema\x12\x9c\x01\n\x0bReloadStore\x12%.cerbos.request.v1.ReloadStoreRequest\x1a\'.cerbos.response.v1.ReloadStoreResponse\"=\x92\x41\x1f\x12\x0cReload storeb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x15\x12\x13/admin/store/reload\x1a\"\x92\x41\x1f\x12\x1d\x43\x65rbos administration service2\xf7\x04\n\x17\x43\x65rbosPlaygroundService\x12\x97\x01\n\x12PlaygroundValidate\x12,.cerbos.request.v1.PlaygroundValidateRequest\x1a..cerbos.response.v1.PlaygroundValidateResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/api/playground/validate:\x01*\x12\x87\x01\n\x0ePlaygroundTest\x12(.cerbos.request.v1.PlaygroundTestRequest\x1a*.cerbos.response.v1.PlaygroundTestResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/playground/test:\x01*\x12\x97\x01\n\x12PlaygroundEvaluate\x12,.cerbos.request.v1.PlaygroundEvaluateRequest\x1a..cerbos.response.v1.PlaygroundEvaluateResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/api/playground/evaluate:\x01*\x12\x8b\x01\n\x0fPlaygroundProxy\x12).cerbos.request.v1.PlaygroundProxyRequest\x1a+.cerbos.response.v1.PlaygroundProxyResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/playground/proxy:\x01*\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xe1\x01\n\x15\x64\x65v.cerbos.api.v1.svcZ6github.com/cerbos/cerbos/api/genpb/cerbos/svc/v1;svcv1\xaa\x02\x11\x43\x65rbos.Api.V1.Svc\x92\x41{\x12?\n\x06\x43\x65rbos\"-\n\x06\x43\x65rbos\x12\x12https://cerbos.dev\x1a\x0finfo@cerbos.dev2\x06latest*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonZ\x11\n\x0f\n\tBasicAuth\x12\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.svc.v1.svc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025dev.cerbos.api.v1.svcZ6github.com/cerbos/cerbos/api/genpb/cerbos/svc/v1;svcv1\252\002\021Cerbos.Api.V1.Svc\222A{\022?\n\006Cerbos\"-\n\006Cerbos\022\022https://cerbos.dev\032\017info@cerbos.dev2\006latest*\001\0022\020application/json:\020application/jsonZ\021\n\017\n\tBasicAuth\022\002\010\001'
  _CERBOSSERVICE._options = None
  _CERBOSSERVICE._serialized_options = b'\222A\036\022\034Cerbos Policy Decision Point'
  _CERBOSSERVICE.methods_by_name['CheckResourceSet']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResourceSet']._serialized_options = b'\222A\237\001\022\005Check\032\223\001[Deprecated: Use CheckResources API instead] Check whether a principal has permissions to perform the given actions on a set of resource instances.X\001\202\323\344\223\002\017\"\n/api/check:\001*'
  _CERBOSSERVICE.methods_by_name['CheckResourceBatch']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResourceBatch']._serialized_options = b'\222A\231\001\022\024Check resource batch\032\177[Deprecated: Use CheckResources API instead] Check a principal\'s permissions to a batch of heterogeneous resources and actions.X\001\202\323\344\223\002\036\"\031/api/check_resource_batch:\001*'
  _CERBOSSERVICE.methods_by_name['CheckResources']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResources']._serialized_options = b'\222Ae\022\017Check resources\032RCheck a principal\'s permissions to a batch of heterogeneous resources and actions.\202\323\344\223\002\031\"\024/api/check/resources:\001*'
  _CERBOSSERVICE.methods_by_name['ServerInfo']._options = None
  _CERBOSSERVICE.methods_by_name['ServerInfo']._serialized_options = b'\222AN\022\026Get server information\0324Get information about the server e.g. server version\202\323\344\223\002\022\022\020/api/server_info'
  _CERBOSSERVICE.methods_by_name['PlanResources']._options = None
  _CERBOSSERVICE.methods_by_name['PlanResources']._serialized_options = b'\222A|\022\016Plan resources\032jProduce a query plan with conditions that must be satisfied for accessing a set of instances of a resource\202\323\344\223\002\030\"\023/api/plan/resources:\001*'
  _CERBOSADMINSERVICE._options = None
  _CERBOSADMINSERVICE._serialized_options = b'\222A\037\022\035Cerbos administration service'
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdatePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdatePolicy']._serialized_options = b'\222A)\022\026Add or update policiesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002&\"\r/admin/policy:\001*Z\022\032\r/admin/policy:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListPolicies']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListPolicies']._serialized_options = b'\222A \022\rList policiesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\021\022\017/admin/policies'
  _CERBOSADMINSERVICE.methods_by_name['GetPolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['GetPolicy']._serialized_options = b'\222A\035\022\nGet policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017\022\r/admin/policy'
  _CERBOSADMINSERVICE.methods_by_name['DisablePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['DisablePolicy']._serialized_options = b'\222A!\022\016Disable policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002D\"\025/admin/policy/disableZ\032\032\025/admin/policy/disable:\001*Z\017*\r/admin/policy'
  _CERBOSADMINSERVICE.methods_by_name['EnablePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['EnablePolicy']._serialized_options = b'\222A \022\rEnable policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\0021\"\024/admin/policy/enableZ\031\032\024/admin/policy/enable:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListAuditLogEntries']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListAuditLogEntries']._serialized_options = b'\222A)\022\026List audit log entriesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\035\022\033/admin/auditlog/list/{kind}'
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdateSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdateSchema']._serialized_options = b'\222A\'\022\024Add or update schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002&\"\r/admin/schema:\001*Z\022\032\r/admin/schema:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListSchemas']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListSchemas']._serialized_options = b'\222A\037\022\014List schemasb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\020\022\016/admin/schemas'
  _CERBOSADMINSERVICE.methods_by_name['GetSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['GetSchema']._serialized_options = b'\222A\035\022\nGet schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017\022\r/admin/schema'
  _CERBOSADMINSERVICE.methods_by_name['DeleteSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['DeleteSchema']._serialized_options = b'\222A \022\rDelete schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017*\r/admin/schema'
  _CERBOSADMINSERVICE.methods_by_name['ReloadStore']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ReloadStore']._serialized_options = b'\222A\037\022\014Reload storeb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\025\022\023/admin/store/reload'
  _CERBOSPLAYGROUNDSERVICE._options = None
  _CERBOSPLAYGROUNDSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundValidate']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundValidate']._serialized_options = b'\202\323\344\223\002\035\"\030/api/playground/validate:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundTest']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundTest']._serialized_options = b'\202\323\344\223\002\031\"\024/api/playground/test:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundEvaluate']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundEvaluate']._serialized_options = b'\202\323\344\223\002\035\"\030/api/playground/evaluate:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundProxy']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundProxy']._serialized_options = b'\202\323\344\223\002\032\"\025/api/playground/proxy:\001*'
  _globals['_CERBOSSERVICE']._serialized_start=218
  _globals['_CERBOSSERVICE']._serialized_end=1584
  _globals['_CERBOSADMINSERVICE']._serialized_start=1587
  _globals['_CERBOSADMINSERVICE']._serialized_end=3576
  _globals['_CERBOSPLAYGROUNDSERVICE']._serialized_start=3579
  _globals['_CERBOSPLAYGROUNDSERVICE']._serialized_end=4210
# @@protoc_insertion_point(module_scope)
